var Connection = require("./connection").Connection,
    Room = require("./room").Room;

/**
 * A campfire client for a specific account.
 * @constructor
 * @param {string} account The name of the account to connect to.
 * @param {string} token The api token to connect with.
 */
exports.Client = function (account, token) {
  /**
   * Convert the specified response data into an array of Rooms.
   * @param {Object} data The server response data.
   * @return {Array.<Room>} An array of Rooms.
   */
  function toRooms(data) {
    var i, rooms;

    rooms = [];
    for (i = 0; i < data.rooms.length; i++) {
      rooms.push(new Room(connection, data.rooms[i]));
    }

    return rooms;
  }

  var connection = new Connection(account, token);

  /**
   * Gets an array of all rooms.
   * @param {function(Array.<Room>)} callback The callback to call with results.
   */
  this.rooms = function (callback) {
    connection.get("/rooms.json", function (data) {
      callback(toRooms(data));
    });
  };

  /**
   * Gets an array of all rooms which the api user is present in.
   * @param {function(Array.<Room>)} callback The callback to call with results.
   */
  this.presence = function (callback) {
    connection.get("/presence.json", function (data) {
      callback(toRooms(data));
    });
  };
};
